<TS language="ko_KR" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>새 주소 만들기</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>새 항목(&amp;N)</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>현재 선택한 주소를 시스템 클립보드로 복사하기</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>복사(&amp;C)</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>QR코드 보이기 (&amp;Q)</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>현재 목록에 선택한 주소 삭제</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>삭제(&amp;D)</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>라벨 복사(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>편집 (&amp;E)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>라벨</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>주소</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(라벨 없음)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>암호문 대화상자</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>암호 입력하기</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>새로운 암호</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>새로운 암호 재확인</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>지갑에 새로운 비밀문구를 입력하세요.&lt;br/&gt;비밀문구를 &lt;b&gt;열 개 이상의 무작위 글자&lt;/b&gt; 혹은 &lt;b&gt;여덟개 이상의 단어로&lt;b&gt; 정하세요.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>지갑 암호화</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>이 작업을 실행하려면 사용자 지갑의 암호가 필요합니다.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>지갑 잠금해제</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>암호 변경</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>지갑 암호화 승인</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>지갑 암호화를 허용하시겠습니까?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>지갑 암호화 완료</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>중요: 본인 지갑 파일에서 만든 예전 백업들은 새로 생성한 암호화된 지갑 파일로 교체됩니다. 보안상 이유로 이전에 암호화하지 않은 지갑 파일 백업은 사용할 수 없게 되니 이른 시일 내로 새로 암호화된 지갑을 사용하시기 바랍니다.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>지갑 암호화 실패</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>지갑 암호화는 내부 에러로 인해 실패했습니다.  당신의 지갑은 암호화 되지 않았습니다.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>지정한 암호가 일치하지 않습니다.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>지갑 잠금해제 실패</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>지갑 해독을 위한 암호가 틀렸습니다.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>지갑 비밀번호가 성공적으로 변경되었습니다.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>경고: Caps Lock키가 켜져있습니다!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>지갑</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>개요(&amp;O)</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>지갑의 일반적 개요를 보여줍니다.</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>보내기(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>받기(&amp;R)</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>거래내역을 검색합니다.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>나가기(&amp;X)</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>어플리케이션 종료</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>옵션(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>보이기/숨기기(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>지갑 암호화(&amp;E)...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>암호문 변경(&amp;C)...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>지갑 암호화에 사용되는 암호를 변경합니다</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>메시지 서명(&amp;M)...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>메시지 확인(&amp;V)...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>디버그 창(&amp;D)</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>디버깅 및 진단 콘솔을 엽니다</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>파일(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>설정(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>도움말(&amp;H)</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>현재까지</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>블록 따라잡기...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>거래 보내기</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>들어오고 있는 거래</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>지갑이 암호화 되었고 현재 잠겨져 있습니다</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>수량:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>바이트:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>금액:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>수수료:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>수수료 이후:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>체인지:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>거래액</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>확인됨</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>주소 복사</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>라벨 복사</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>거래액 복사</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>거래 아이디 복사</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>수량 복사</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>수수료 복사</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>수수료 이후 복사</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>bytes 복사</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>잔돈 복사</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>예</translation>
    </message>
    <message>
        <source>no</source>
        <translation>아니요</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(라벨 없음)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>%1로부터 변경 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(잔돈)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>주소 편집</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>라벨(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>주소(&amp;A)</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>새 받는 주소</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>새 보내는 주소</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>받는 주소 편집</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>보내는 주소 편집</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>입력된 주소는"%1" 이미 주소록에 있습니다.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>지갑을 잠금해제 할 수 없습니다.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>새로운 키 생성이 실패하였습니다.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>환경설정</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>메인(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>네트워크(&amp;N)</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>사용중인 &amp;UPnP 포트 매핑</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>포트(&amp;P):</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>프록시의 포트번호입니다 (예: 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>창(&amp;W)</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>창을 최소화 하면 트레이에 아이콘만 표시합니다.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>작업 표시줄 대신 트레이로 최소화(&amp;M)</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>닫을때 최소화(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>표시(&amp;D)</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>사용자 인터페이스 언어(&amp;L):</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>거래액을 표시할 단위(&amp;U):</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>인터페이스에 표시하고 코인을 보낼때 사용할 기본 최소화 단위를 선택하십시오.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>확인(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>취소(&amp;C)</translation>
    </message>
    <message>
        <source>default</source>
        <translation>기본값</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>지정한 프록시 주소가 잘못되었습니다.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>유형</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>사용 가능</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>당신의 현재 사용 가능한 잔액</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>아직 사용 불가능:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>총액:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>당신의 현재 총액</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>클라이언트 버전</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>정보(&amp;I)</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>시작 시간</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>연결 수</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>블럭 체인</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>현재 블럭 수</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>최종 블럭 시각</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>열기(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>지우기(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>콘솔(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>네트워크 트래픽(&amp;N)</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>총액</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>로그 파일 디버그</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>콘솔 초기화</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>기록을 찾아보려면 위 아래 화살표 키를, 화면을 지우려면 &lt;b&gt;Ctrl-L&lt;/b&gt;키를 사용하십시오.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>사용할 수 있는 명령을 둘러보려면 &lt;b&gt;help&lt;/b&gt;를 입력하십시오.</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 바이트</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 킬로바이트</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 메가바이트</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 기가바이트</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>코인들 보내기</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>입력...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>자동 선택</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>자금이 부족합니다!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>수량:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>바이트:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>거래액:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>수수료:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>수수료 이후:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>다수의 수령인들에게 한번에 보내기</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>수령인 추가하기(&amp;R)</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>모두 지우기(&amp;A)</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>전송 기능 확인</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>보내기(&amp;E)</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>수량 복사</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>거래액 복사</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>수수료 복사</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>수수료 이후 복사</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>bytes 복사</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>잔돈 복사</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(라벨 없음)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>금액(&amp;M):</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>송금할 대상(&amp;T):</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>메시지:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>라벨(&amp;L):</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>클립보드로 부터 주소 붙여넣기</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>서명 - 싸인 / 메시지 확인</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>메시지 서명(&amp;S)</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>클립보드로 부터 주소를 복사하기</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>여기에 서명하려는 메시지를 입력하십시오</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>현재 서명을 시스템 클립보드에 복사</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>메시지에 서명(&amp;M)</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>메시지 필드의 모든 서명 재설정</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>모두 지우기(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>메시지 검증(&amp;V)</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>모든 검증 메시지 필드 재설정</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>이 창은 거래의 세부내역을 보여줍니다</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>형식</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>받은 주소</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>보낸 주소</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Received with</source>
        <translation>받은 주소</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>보낸 주소</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>주소 복사</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>라벨 복사</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>거래액 복사</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>트랜잭션 아이디 복사</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>라벨 수정</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>거래 세부 내역 보기</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>확인됨</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>형식</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>라벨</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>주소</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>아이디</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>범위:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>상대방</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>어떤 포트도 반응하지 않습니다. 사용자 반응=0 만약 원한다면</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>잘못된 -proxy 주소입니다: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>주소를 불러오는 중...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>-onlynet에 지정한 네트워크를 알 수 없습니다: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>자금 부족</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>블럭 인덱스를 불러오는 중...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>지갑을 불러오는 중...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>기본 계좌에 기록할 수 없습니다</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>재검색 중...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>로딩 완료</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
</context>
</TS>